@@ -31,12 +31,14 @@ use backoff::{backoff::Backoff, ExponentialBackoff};
 use bls::PublicKey as BlsPublicKey;
 use futures::future;
 use resource_proof::ResourceProof;
+use std::collections::BTreeMap;
 use tokio::time::sleep;
 use tokio::{sync::mpsc, time::Duration};
 use tracing::Instrument;
 use xor_name::Prefix;
 
-const JOIN_SHARE_EXPIRATION_DURATION: Duration = Duration::from_secs(300);
+// arbitrarily long. No join in a non splitting section should fail to get signature shares in anything like a few minutes
+const JOIN_SHARE_EXPIRATION_DURATION: Duration = Duration::from_secs(900);
 
 /// Join the network as new node.
 ///
@@ -73,10 +75,9 @@ struct Join<'a> {
     node: Node,
     prefix: Prefix,
     prefix_map: NetworkPrefixMap,
-    signature_aggregator: SignatureAggregator,
+    signature_aggregators: BTreeMap<BlsPublicKey, SignatureAggregator>,
     node_state_serialized: Option<Vec<u8>>,
     backoff: ExponentialBackoff,
-    aggregation_errors: usize,
 }
 
 impl<'a> Join<'a> {
@@ -92,9 +93,7 @@ impl<'a> Join<'a> {
             node,
             prefix: Prefix::default(),
             prefix_map,
-            signature_aggregator: SignatureAggregator::with_expiration(
-                JOIN_SHARE_EXPIRATION_DURATION,
-            ),
+            signature_aggregators: BTreeMap::default(),
             node_state_serialized: None,
             backoff: ExponentialBackoff {
                 initial_interval: Duration::from_millis(50),
@@ -102,7 +101,6 @@ impl<'a> Join<'a> {
                 max_elapsed_time: Some(Duration::from_secs(60)),
                 ..Default::default()
             },
-            aggregation_errors: 0,
         }
     }
 
@@ -170,12 +168,6 @@ impl<'a> Join<'a> {
                     error!("Network is set to not taking any new joining node, try join later.");
                     return Err(Error::TryJoinLater);
                 }
-                JoinResponse::Rejected(JoinRejectionReason::DKGUnderway) => {
-                    error!("The Section we are trying to join is going through DKG, backing off and retrying again");
-                    self.send_join_requests(join_request.clone(), &recipients, section_key, true)
-                        .await?;
-                    continue;
-                }
                 JoinResponse::Approval {
                     section_auth,
                     genesis_key,
@@ -231,30 +223,14 @@ impl<'a> Join<'a> {
 
                     let sig_pk = sig_share.public_key_set.public_key();
 
-                    if sig_pk != section_key {
-                        info!(
-                            "ApprovalShare from {} has the wrong signing section key (expected: {:?}, actual: {:?}), retrying",
-                            sender,
-                            section_key,
-                            sig_share.public_key_set.public_key()
-                        );
-
-                        let join_request = JoinRequest {
-                            section_key,
-                            resource_proof_response: None,
-                            aggregated: None,
-                        };
-                        self.send_join_requests(join_request, &[sender], section_key, true)
-                            .await?;
-                        continue;
-                    }
+                    // get the aggregator or make a new one for this new section public key
+                    let aggregator =
+                        self.signature_aggregators.entry(sig_pk).or_insert_with(|| {
+                            SignatureAggregator::with_expiration(JOIN_SHARE_EXPIRATION_DURATION)
+                        });
 
                     info!("Aggregating received ApprovalShare from {:?}", sender);
-                    match self
-                        .signature_aggregator
-                        .add(&serialized_details, sig_share.clone())
-                        .await
-                    {
+                    match aggregator.add(&serialized_details, sig_share.clone()).await {
                         Ok(sig) => {
                             info!("Successfully aggregated ApprovalShares for joining the network");
 
@@ -289,22 +265,15 @@ impl<'a> Join<'a> {
                                 "Error received as part of signature aggregation during join: {:?}",
                                 error
                             );
-                            self.aggregation_errors += 1;
 
-                            // if we've have aggregation errors, we should start fresh as there's likely been a key change
-                            if self.aggregation_errors >= recipients.len() / 2 {
+                            if sig_pk != section_key {
+                                // if we've have aggregation errors, we attempt a fresh join as there's likely been a key change
                                 let join_request = JoinRequest {
                                     section_key,
                                     resource_proof_response: None,
                                     aggregated: None,
                                 };
 
-                                // reset aggregation
-                                self.aggregation_errors = 0;
-                                self.signature_aggregator = SignatureAggregator::with_expiration(
-                                    JOIN_SHARE_EXPIRATION_DURATION,
-                                );
-
                                 self.send_join_requests(
                                     join_request,
                                     &recipients,
